import java.io.*;
import java.util.Scanner;

import javax.swing.*;

/**
 * Blosum80 - a class to represent the information in the BLOSUM80 similarity table for amino acids
 * 
 * @author CS faculty
 * @version Fall 2012
 */
public class Blosum80 implements SimilaritySchemeInterface {
    
    // the file containing the table
    private final String blosum80File = "blosum80.txt";
    // the amino acids represented in the table; the order in the String represents their order in the table
    private final String aminoAcids = "ARNDCQEGHILKMFPSTWYVBJZX";
    // the matrix of similarity values
    private int[][] matrix;
    
    // the gap penalty
    private static final int GAP = -1;

    /**
     * Contructs a BLOSUM80 similarity matrix
     */
    public Blosum80() {
       matrix = new int[aminoAcids.length()][aminoAcids.length()];
       try {
           Scanner scanner = new Scanner(new File(blosum80File));
           for (int y = 0; y < aminoAcids.length(); y++) {
               for (int x = 0; x < aminoAcids.length(); x++) {
                   matrix[x][y] = scanner.nextInt();
                }
            }
            scanner.close();   
        } catch (Exception e) {
            System.out.println("Problem reading BLOSUM80 matrix file");
        }
    }
    
    // return the similarity between two amino acids (acid1 and acid2)
    public int getSimilarity(char acid1, char acid2) {
        return matrix[aminoAcids.indexOf(acid1+"")][aminoAcids.indexOf(acid2+"")];
    }

    // return the gap score
    public int getGapScore() {
        return GAP;
    }

    // return the string that represents the matrix of similarity values
    public String toString() {
        String result = "";
        for (int y = 0; y < aminoAcids.length(); y++) {
            result = result + aminoAcids.charAt(y) + " ";
            for (int x = 0; x < aminoAcids.length(); x++) {
                result = result + "\t" + matrix[x][y];
            }
            result = result + "\n";
        }
        return result;
    }
}
